==> libminigui-3.2.3.tar.gz: libminigui-3.2.3/src/sysres/bmp/skin_pb_htrack.gif.c <==
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "skin_pb_htrack.gif"

unsigned char _mgir_gif_skin_pb_htrack_data[]={
	0x47,0x49,0x46,0x38,0x39,0x61,0x13,0x00,	0x0F,0x00,0xD5,0x00,0x00,0xF9,0xF9,0xF9,
	0xF3,0xF3,0xF3,0xF0,0xF0,0xF0,0xEE,0xEE,	0xEE,0xEB,0xEB,0xEB,0xE7,0xE7,0xE7,0xDD,
	0xDD,0xDD,0xDB,0xDB,0xDB,0xD9,0xD9,0xD9,	0xD8,0xD8,0xD8,0xD4,0xD4,0xD4,0xCE,0xCE,
	0xCE,0xCD,0xCD,0xCD,0xCB,0xCB,0xCB,0xCA,	0xCA,0xCA,0xC2,0xC2,0xC2,0xC1,0xC1,0xC1,
	0xBC,0xBC,0xBC,0xB9,0xB9,0xB9,0xB5,0xB5,	0xB5,0xA6,0xA6,0xA6,0xA3,0xA3,0xA3,0xA2,
	0xA2,0xA2,0x9F,0x9F,0x9F,0x9B,0x9B,0x9B,	0x9A,0x9A,0x9A,0x97,0x97,0x97,0x95,0x95,
	0x95,0x93,0x93,0x93,0x8D,0x8D,0x8D,0x89,	0x89,0x89,0x7E,0x7E,0x7E,0x7D,0x7D,0x7D,
	0x78,0x78,0x78,0x6D,0x6D,0x6D,0x66,0x66,	0x66,0x63,0x63,0x63,0x60,0x60,0x60,0x5C,
	0x5C,0x5C,0x56,0x56,0x56,0x4E,0x4E,0x4E,	0x4D,0x4D,0x4D,0x4A,0x4A,0x4A,0x48,0x48,
	0x48,0x45,0x45,0x45,0x44,0x44,0x44,0x43,	0x43,0x43,0x3F,0x3F,0x3F,0x3A,0x3A,0x3A,
	0x38,0x38,0x38,0x25,0x25,0x25,0x1B,0x1B,	0x1B,0x19,0x19,0x19,0x00,0x00,0x00,0xFF,
	0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x21,0xF9,0x04,
	0x01,0x00,0x00,0x36,0x00,0x2C,0x00,0x00,	0x00,0x00,0x13,0x00,0x0F,0x00,0x00,0x06,
	0x5B,0x40,0x87,0xAC,0x46,0x2C,0x1A,0x8F,	0xB3,0xC7,0x86,0x96,0x00,0x38,0x9F,0x50,
	0xA8,0xC9,0x43,0x5A,0x45,0xAF,0x50,0x8C,	0x09,0x05,0xC2,0x7A,0x21,0xAC,0x96,0xC5,
	0x8B,0x3D,0xC0,0x5C,0x11,0xF2,0x95,0x10,	0x53,0x35,0xD4,0x51,0xC1,0x2B,0x75,0x80,
	0x47,0x59,0x25,0x83,0xFD,0x19,0x38,0x89,	0x14,0x7B,0x4E,0x03,0x23,0x1F,0x6F,0x81,
	0x05,0x21,0x1C,0x12,0x81,0x00,0x08,0x1D,	0x15,0x14,0x8C,0x0B,0x17,0x12,0x1A,0x8C,
	0x12,0x13,0x0C,0x18,0x1B,0x9C,0x9D,0x9E,	0x9F,0x19,0x0D,0x41,0x00,0x3B
};
#endif //_MGINCORE_RES

==> libminigui-4.0.2.tar.gz: libminigui-4.0.2/src/sysres/bmp/skin_pb_htrack.gif.c <==
///////////////////////////////////////////////////////////////////////////////
//
//                          IMPORTANT NOTICE
//
// The following open source license statement does not apply to any
// entity in the Exception List published by FMSoft.
//
// For more information, please visit:
//
// https://www.fmsoft.cn/exception-list
//
//////////////////////////////////////////////////////////////////////////////
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "skin_pb_htrack.gif"

const unsigned char _mgir_gif_skin_pb_htrack_data[]={
	0x47,0x49,0x46,0x38,0x39,0x61,0x13,0x00,	0x0F,0x00,0xD5,0x00,0x00,0xF9,0xF9,0xF9,
	0xF3,0xF3,0xF3,0xF0,0xF0,0xF0,0xEE,0xEE,	0xEE,0xEB,0xEB,0xEB,0xE7,0xE7,0xE7,0xDD,
	0xDD,0xDD,0xDB,0xDB,0xDB,0xD9,0xD9,0xD9,	0xD8,0xD8,0xD8,0xD4,0xD4,0xD4,0xCE,0xCE,
	0xCE,0xCD,0xCD,0xCD,0xCB,0xCB,0xCB,0xCA,	0xCA,0xCA,0xC2,0xC2,0xC2,0xC1,0xC1,0xC1,
	0xBC,0xBC,0xBC,0xB9,0xB9,0xB9,0xB5,0xB5,	0xB5,0xA6,0xA6,0xA6,0xA3,0xA3,0xA3,0xA2,
	0xA2,0xA2,0x9F,0x9F,0x9F,0x9B,0x9B,0x9B,	0x9A,0x9A,0x9A,0x97,0x97,0x97,0x95,0x95,
	0x95,0x93,0x93,0x93,0x8D,0x8D,0x8D,0x89,	0x89,0x89,0x7E,0x7E,0x7E,0x7D,0x7D,0x7D,
	0x78,0x78,0x78,0x6D,0x6D,0x6D,0x66,0x66,	0x66,0x63,0x63,0x63,0x60,0x60,0x60,0x5C,
	0x5C,0x5C,0x56,0x56,0x56,0x4E,0x4E,0x4E,	0x4D,0x4D,0x4D,0x4A,0x4A,0x4A,0x48,0x48,
	0x48,0x45,0x45,0x45,0x44,0x44,0x44,0x43,	0x43,0x43,0x3F,0x3F,0x3F,0x3A,0x3A,0x3A,
	0x38,0x38,0x38,0x25,0x25,0x25,0x1B,0x1B,	0x1B,0x19,0x19,0x19,0x00,0x00,0x00,0xFF,
	0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x21,0xF9,0x04,
	0x01,0x00,0x00,0x36,0x00,0x2C,0x00,0x00,	0x00,0x00,0x13,0x00,0x0F,0x00,0x00,0x06,
	0x5B,0x40,0x87,0xAC,0x46,0x2C,0x1A,0x8F,	0xB3,0xC7,0x86,0x96,0x00,0x38,0x9F,0x50,
	0xA8,0xC9,0x43,0x5A,0x45,0xAF,0x50,0x8C,	0x09,0x05,0xC2,0x7A,0x21,0xAC,0x96,0xC5,
	0x8B,0x3D,0xC0,0x5C,0x11,0xF2,0x95,0x10,	0x53,0x35,0xD4,0x51,0xC1,0x2B,0x75,0x80,
	0x47,0x59,0x25,0x83,0xFD,0x19,0x38,0x89,	0x14,0x7B,0x4E,0x03,0x23,0x1F,0x6F,0x81,
	0x05,0x21,0x1C,0x12,0x81,0x00,0x08,0x1D,	0x15,0x14,0x8C,0x0B,0x17,0x12,0x1A,0x8C,
	0x12,0x13,0x0C,0x18,0x1B,0x9C,0x9D,0x9E,	0x9F,0x19,0x0D,0x41,0x00,0x3B
};
#endif //_MGINCORE_RES
